pub const AUTHORS: &'static str = env!("CARGO_PKG_AUTHORS");
pub const VERSION: &'static str = env!("CARGO_PKG_VERSION");
pub const BUILDTD: &'static str = env!("BUILD_TIMEDATE");
pub const REVISION: &'static str = env!("VCS_COMMIT_HASH");
pub const REVDATE: &'static str = env!("VCS_COMMIT_DATE");

pub const SOCK_LOCATION: &'static str = "cubemapper.sock";

use serde::{Deserialize, Serialize};
use thiserror::Error;

pub type Result<T> = std::result::Result<T, Error>;

#[derive(Debug, Error)]
pub enum Error {
    #[error("IO error {0}")]
    IO(#[from] std::io::Error),

    #[error("bincode error {0}")]
    SerdeCbor(#[from] bincode::Error),

    #[error("Engine Exited Unsuccessfully")]
    BadEngineExit(i32),

    #[error("{0}")]
    Other(&'static str),
}

#[allow(non_snake_case)]
#[derive(Serialize, Deserialize, Debug)]
pub struct DNR {
    pub HDR: bool,
    pub LDR: bool,
}

#[derive(Serialize, Deserialize, Debug)]
pub struct Job {
    pub map: String,
    pub dnr: DNR,
}

#[derive(Serialize, Deserialize, Debug)]
pub enum Message {
    Job(Job),
    Ack(bool),
    Success((i32, String)),
    Failure((i32, String)),
}
